* Encoding: UTF-8.

set seed = 4711.

* OMS.
DATASET CLOSE MCOLS.
DATASET DECLARE  MCOLS.
OMS
  /SELECT TABLES
  /IF COMMANDS=['Regression'] SUBTYPES=['Coefficients']
  /DESTINATION FORMAT=SAV NUMBERED=TableNumber_
   OUTFILE='MCOLS' VIEWER=YES.

DATASET CLOSE MCHLM.
DATASET DECLARE  MCHLM.
OMS
  /SELECT TABLES
  /IF COMMANDS=['Mixed'] SUBTYPES=['Tests of Fixed Effects']
  /DESTINATION FORMAT=SAV NUMBERED=TableNumber_
   OUTFILE='MCHLM' VIEWER=YES.


DEFINE RunSimulations ()
!DO !ind=1 !TO 1000

input program.
loop #j = 1 to 100.
   compute id = #j.
   compute w = uniform(1).
   compute u0j = normal(1).
   leave id w u0j.
   loop #i = 1 to 30.
     compute x = normal(1.5).
     compute y = u0j + normal(2).
     end case.
   end loop.
end loop.
end file.
end input program.
exe.

* OLS-Regression.
REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI(95) R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT y
  /METHOD=ENTER x w.

* HLM .
mixed y with x w
  /print=solution testcov
  /fixed = x w 
  /random intercept | subject(id).

!DOEND
!ENDDEFINE.

RunSimulations.

OMSEND.

* Auswerten OLS.
DATASET ACTIVATE MCOLS.

* Mikroregressor.
USE ALL.
COMPUTE filter_$=(Var2 = "x").
VARIABLE LABELS filter_$ 'Var2 = "x" (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

FREQUENCIES VARIABLES=RegressionskoeffizientB Std.Fehler
  /FORMAT=NOTABLE
  /STATISTICS=STDDEV MEAN
  /ORDER=ANALYSIS.

do if (Sig < 0.05).
compute signifikant = 1.
else.
compute signifikant = 0.
end if.
execute.

FREQUENCIES VARIABLES=signifikant
  /ORDER=ANALYSIS..

* Makroregressor.
USE ALL.
COMPUTE filter_$=(Var2 = "w").
VARIABLE LABELS filter_$ 'Var2 = "w" (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

FREQUENCIES VARIABLES=RegressionskoeffizientB Std.Fehler
  /FORMAT=NOTABLE
  /STATISTICS=STDDEV MEAN
  /ORDER=ANALYSIS.

do if (Sig < 0.05).
compute signifikant = 1.
else.
compute signifikant = 0.
end if.
execute.

FREQUENCIES VARIABLES=signifikant
  /ORDER=ANALYSIS.


* Auswerten HLM.
DATASET ACTIVATE MCHLM.

* Mikroregressor.
USE ALL.
COMPUTE filter_$=(Var1 = "x").
VARIABLE LABELS filter_$ 'Var1 = "x" (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

do if (Sig < 0.05).
compute signifikant = 1.
else.
compute signifikant = 0.
end if.
execute.

FREQUENCIES VARIABLES=signifikant
  /ORDER=ANALYSIS.

* Makroregressor.
USE ALL.
COMPUTE filter_$=(Var1 = "w").
VARIABLE LABELS filter_$ 'Var1 = "w" (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

do if (Sig < 0.05).
compute signifikant = 1.
else.
compute signifikant = 0.
end if.
execute.

FREQUENCIES VARIABLES=signifikant
  /ORDER=ANALYSIS.



